==> 15.0.16.0-TIV-PROSPECT-NORCDM-IF0003.tar: patches/15.0.16.0.3.1/install.sh <==
#!/bin/ksh
#> This script will install Prospect 8.0 / Nortel MTX16 RP16 HF03 hotfix. This Hotfix can be applied#to RP16.0,RP16.1,RP16.2,RP16.3,RP16.4 or RP16.5 systems
#> for 
#> Usage: install.sh {-help|-install|-uninstall}
#

InstallFileset='
vendor/Nortel/MSC/1.3/scripts/sentry.sh
vendor/Nortel/MSC/NortelMTX.build
'

########################################################
# set paths and files

RELEASE="15.0.16.0.3.1"
SourceDir="${FLEXPM_HOME}/patches/${RELEASE}"
SourceDir1="${FLEXPM_HOME}/patches/${RELEASE}/nortel"
BackupDir="${FLEXPM_HOME}/patches/${RELEASE}/backup/"

########################################################

### give help
  ToolName=`basename $0`
  runTime=`date '+%Y%m%d%H%M'`
  case $1 in
  -help|-usage)
    echo "${ToolName} usage information -- " 1>&2
    grep "^#> " $0 1>&2
    grep "^#>  \"" $0 1>&2
    exit 2
    ;;
  esac

# Check env settings

  if [ $# -ne 1 ]; then
    echo "Usage $0 {-help | -install | -uninstall}"
    exit;
  fi

  echo "Checking environment....."
  if ! [[ -d ${FLEXPM_HOME} ]]; then
    echo "Env variable FLEXPM_HOME must be set to appropriate dir before installation."
    exit;
  fi

  if [[ -z ${DB_CONNECT} ]]; then
     echo "Env variable DB_CONNECT must be set to approriate database connection values."
     exit;
  fi
 


  
cd $SourceDir
# Source and destination directories

  case $1 in
  -install)
    echo "Installing patch..."
  if [[ -d ${BackupDir} ]]; then
           echo "Patch ${VERSION} may have been already applied. Aborting patch installation.\n"
           exit
  else
           mkdir -p -m 744 ${BackupDir}
  fi
    # Updating the NortelMTX.build file
    chmod +w ${FLEXPM_HOME}/vendor/Nortel/MSC/NortelMTX.build

    echo "Registration of ${RELEASE} started."
    chmod +x $FLEXPM_HOME/pm/adm/register
    register start ${SourceDir1}/vendor/Nortel/MSC/NortelMTX.build
    [[ $? -ne 0 ]] && exit 1;


    
    echo "Files to be updated/added ..."

    cd $SourceDir1
   touch ${BackupDir}/backup_source.tar

    for f in ${InstallFileset}
    do
        echo "${FLEXPM_HOME}/${f}"
        if [[ -a ${FLEXPM_HOME}/${f} ]]; then
        # permissions
        chmod u+w ${FLEXPM_HOME}/${f}
		
        # Keep appeding files to the backup tarball 
        tar -rf ${BackupDir}/backup_source.tar $FLEXPM_HOME/${f}

        fi
        # install files
	cp -pf ${SourceDir1}/${f} ${FLEXPM_HOME}/${f}
		
	# permissions
	#chmod u-w ${FLEXPM_HOME}/${f}
	chmod u+x ${FLEXPM_HOME}/${f}
    done
 
    register complete ${SourceDir1}/vendor/Nortel/MSC/NortelMTX.build

    echo "Installation completed successfully."
    ;;

  -uninstall)

  echo ""
    echo "+ Attempting to restore backup files ..."

    cd ${FLEXPM_HOME}

    if [[ -f ${BackupDir}/backup_source.tar ]];
    then
      echo "+ Found backup files... restoring ..."
      for file in `tar -tf ${BackupDir}/backup_source.tar`
      do
         if [ -f $file ]
         then
           chmod +w $file
         fi
      done

      tar -xvf ${BackupDir}/backup_source.tar


    # Remove the component registration for this patch
      COMP_REG=`show_installed | grep 'rev 15.0.16.0.3 b1'`
      if [[ ! -z ${COMP_REG} ]]; then
sq1="select component_version_id from component_version where revision = '15.0.16.0.3' and component_id in (select component_id from component where component_name in ('NortelMTX16'))"
sq3="delete component_history where component_version_id in ( $sq1 )"
sq4="delete component_installed where component_version_id in ( $sq1 )"
sq5="delete component_version where component_version_id in ( $sq1 )"
sqlplus -s /nolog <<EOF
connect $DBUSER/$DBPASSWD@$DBSID
${sq3};
${sq4};
${sq5};
exit;
EOF
      fi
    else
      echo "+ Backup files not found... exiting..."
      exit;
    fi
    cd ${START_DIR}

  echo "End: " `date`

  echo "Un-installation Complete."
    break
    ;; 

  * )
    echo "Unknown option"
    echo "Usage: install.sh {-help|-install|-uninstall}"
    ;;
  esac

==> 16.0.16.2-TIV-PROSPECT-NORCDM-IF0003.tar: patches/16.0.16.2.3.1/install.sh <==
#!/bin/ksh
#> This script will install Prospect 8.0 / Nortel MTX16 RP16.2 HF03 hotfix
#> for  IZ44075 -MTXPM OM GROUP SMSZONPG PARSING INCORRECTLY
#> Usage: install.sh {-help|-install|-uninstall}
#

InstallFileset='
vendor/Nortel/MSC/1.3/MSC/config/colDef_R15/colDef_LOCAREA
vendor/Nortel/MSC/1.3/MSC/config/colDef_R16/colDef_LOCAREA
vendor/Nortel/MSC/1.3/MSC/data/ParserState.txt
vendor/Nortel/MSC/NortelMTX.build
'

########################################################
# set paths and files

RELEASE="16.0.16.2.3.1"
SourceDir="${FLEXPM_HOME}/patches/${RELEASE}"
SourceDir1="${FLEXPM_HOME}/patches/${RELEASE}/nortel"
BackupDir="${FLEXPM_HOME}/patches/${RELEASE}/backup/"

########################################################

### give help
  ToolName=`basename $0`
  runTime=`date '+%Y%m%d%H%M'`
  case $1 in
  -help|-usage)
    echo "${ToolName} usage information -- " 1>&2
    grep "^#> " $0 1>&2
    grep "^#>  \"" $0 1>&2
    exit 2
    ;;
  esac

# Check env settings

  if [ $# -ne 1 ]; then
    echo "Usage $0 {-help | -install | -uninstall}"
    exit;
  fi

  echo "Checking environment....."
  if ! [[ -d ${FLEXPM_HOME} ]]; then
    echo "Env variable FLEXPM_HOME must be set to appropriate dir before installation."
    exit;
  fi

  if [[ -z ${DB_CONNECT} ]]; then
     echo "Env variable DB_CONNECT must be set to approriate database connection values."
     exit;
  fi
 
cd $SourceDir
# Source and destination directories

  case $1 in
  -install)
    echo "Installing patch..."
  if [[ -d ${BackupDir} ]]; then
           echo "Patch ${VERSION} may have been already applied. Aborting patch installation.\n"
           exit
  else
           mkdir -p -m 744 ${BackupDir}
  fi
    # Updating the NortelMTX.build file
    chmod +w ${FLEXPM_HOME}/vendor/Nortel/MSC/NortelMTX.build

    echo "Registration of ${RELEASE} started."
    chmod +x $FLEXPM_HOME/pm/adm/register
    register start ${SourceDir1}/vendor/Nortel/MSC/NortelMTX.build
    [[ $? -ne 0 ]] && exit 1;
    
    echo "Files to be updated/added ..."

    cd $SourceDir1
   touch ${BackupDir}/backup_source.tar

    for f in ${InstallFileset}
    do
        echo "${FLEXPM_HOME}/${f}"
        if [[ -a ${FLEXPM_HOME}/${f} ]]; then
        # permissions
        chmod u+w ${FLEXPM_HOME}/${f}
		
        # Keep appeding files to the backup tarball 
        tar -rf ${BackupDir}/backup_source.tar $FLEXPM_HOME/${f}

        fi
        # install files
	cp -pf ${SourceDir1}/${f} ${FLEXPM_HOME}/${f}
		
	# permissions
	#chmod u-w ${FLEXPM_HOME}/${f}
	chmod u+x ${FLEXPM_HOME}/${f}
    done

    #gw
    echo "Updating MSC loader ..."
    cd $FLEXPM_HOME/vendor/Nortel/MSC/1.3/MSC/config
    make drop
    make global_tmp
   #Remove the LoaderControltxt  from config and data directory so new ones are built
    rm LoaderControl.txt DatabaseTable.txt DatabaseFile.txt ../data/LoaderControl.txt ../data/DatabaseTable.txt ../data/DatabaseFile.txt
    make build_loaders

    register complete ${SourceDir1}/vendor/Nortel/MSC/NortelMTX.build

    echo "Installation completed successfully."
    ;;

  -uninstall)

  echo ""
    echo "+ Attempting to restore backup files ..."

    cd ${FLEXPM_HOME}

    if [[ -f ${BackupDir}/backup_source.tar ]];
    then
      echo "+ Found backup files... restoring ..."
      for file in `tar -tf ${BackupDir}/backup_source.tar`
      do
         if [ -f $file ]
         then
           chmod +w $file
         fi
      done

      tar -xvf ${BackupDir}/backup_source.tar
    cd $FLEXPM_HOME/vendor/Nortel/MSC/1.3/MSC/config
    make drop
    make global_tmp
   #Remove the LoaderControltxt  from config and data directory so new ones are built
    rm LoaderControl.txt DatabaseTable.txt DatabaseFile.txt ../data/LoaderControl.txt ../data/DatabaseTable.txt ../data/DatabaseFile.txt
    make build_loaders


    # Remove the component registration for this patch
      COMP_REG=`show_installed | grep 'rev 16.0.16.2.3 b1'`
      if [[ ! -z ${COMP_REG} ]]; then
sq1="select component_version_id from component_version where revision = '16.0.16.2.3' and component_id in (select component_id from component where component_name in ('NortelMTX16'))"
sq3="delete component_history where component_version_id in ( $sq1 )"
sq4="delete component_installed where component_version_id in ( $sq1 )"
sq5="delete component_version where component_version_id in ( $sq1 )"
sqlplus -s /nolog <<EOF
connect $DBUSER/$DBPASSWD@$DBSID
${sq3};
${sq4};
${sq5};
exit;
EOF
      fi
    else
      echo "+ Backup files not found... exiting..."
      exit;
    fi
    cd ${START_DIR}

  echo "End: " `date`

  echo "Un-installation Complete."
    break
    ;; 

  * )
    echo "Unknown option"
    echo "Usage: install.sh {-help|-install|-uninstall}"
    ;;
  esac
